
# formulon

[![PyPI - Version](https://img.shields.io/pypi/v/formulon.svg)](https://pypi.org/project/formulon)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/formulon.svg)](https://pypi.org/project/formulon)
[![License](https://img.shields.io/pypi/l/formulon.svg)](https://spdx.org/licenses/MIT.html)

**formulon** is a lightweight, open-source Python library that provides commonly used
**classical physics formulas** with automatic input validation.This project is designed 
and developed by SRI KALEESWARAR S, a Physics post graduate student from India.Its a 
open source,free to use library.I thank my professors from Scott Christian college, special mention to 
Kaniyam.com and open science labs

It is designed for **students, educators, and scientific Python users**, with support
for both scalar and NumPy-based vector calculations.

---

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Features](#features)
- [License](#license)

---

## Installation

Install formulon from PyPI:

```bash
pip install formulon

## License

formulon is distributed under the terms of the MIT License.

MIT License (Summary)

Free to use, modify, and distribute

Permitted for commercial and academic use

Provided without warranty

Full license text:
https://spdx.org/licenses/MIT.html
>>>>>>> 0350b6d (Welcome,Im born now)
